import React, { useState, useEffect } from 'react';

const generateServiceWorkerScript = (config) => {
  const cacheName = config.cacheName || "static-cache";
  const version = config.version || "v1";
  const cacheKey = `${cacheName}-${version}`;
  return `
// Generated Service Worker for react-static-cache
const CACHE_NAME = '${cacheKey}';
const URLS_TO_CACHE = ${JSON.stringify(config.urls)};

self.addEventListener('install', (event) => {
  event.waitUntil(
    caches.open(CACHE_NAME)
      .then((cache) => {
        console.log('Cache opened');
        return cache.addAll(URLS_TO_CACHE);
      })
      .catch((error) => {
        console.error('Failed to cache resources:', error);
      })
  );
});

self.addEventListener('fetch', (event) => {
  if (URLS_TO_CACHE.includes(new URL(event.request.url).pathname)) {
    event.respondWith(
      caches.match(event.request)
        .then((response) => {
          if (response) {
            return response;
          }

          return fetch(event.request).then((networkResponse) => {
            const responseToCache = networkResponse.clone();

            caches.open(CACHE_NAME).then((cache) => {
              cache.put(event.request, responseToCache);
            });

            return networkResponse;
          });
        })
        .catch((error) => {
          console.error('Failed to fetch resource:', error);
        })
    );
  }
});

self.addEventListener('activate', (event) => {
  event.waitUntil(
    caches.keys().then((cacheNames) => {
      return Promise.all(
        cacheNames
          .filter((name) => name.startsWith('${cacheName}') && name !== CACHE_NAME)
          .map((name) => caches.delete(name))
      );
    })
  );
});
`;
};

const useStaticCache = (config) => {
  const [registration, setRegistration] = useState(null);
  const [error, setError] = useState(null);
  const [isReady, setIsReady] = useState(false);
  useEffect(() => {
    const initialize = async () => {
      if ("serviceWorker" in navigator) {
        try {
          const swScript = generateServiceWorkerScript(config);
          const blob = new Blob([swScript], { type: "text/javascript" });
          const swUrl = URL.createObjectURL(blob);
          const reg = await navigator.serviceWorker.register(swUrl, { scope: "/" });
          setRegistration(reg);
          setIsReady(true);
          URL.revokeObjectURL(swUrl);
        } catch (err) {
          setError(err instanceof Error ? err : new Error("Failed to register service worker"));
        }
      } else {
        setError(new Error("Service workers not supported"));
      }
    };
    initialize().then();
  }, [config]);
  return { isReady, error, registration };
};

const CacheProvider = ({
  children,
  ...config
}) => {
  useStaticCache(config);
  return /* @__PURE__ */ React.createElement(React.Fragment, null, children);
};

const inspectCache = async (cacheName) => {
  try {
    if (!cacheName) {
      const cacheNames = await caches.keys();
      const allCaches = {};
      for (const name of cacheNames) {
        const cache2 = await caches.open(name);
        const keys2 = await cache2.keys();
        allCaches[name] = keys2.map((key) => key.url);
      }
      console.group("All Cached Assets:");
      Object.entries(allCaches).forEach(([name, urls2]) => {
        console.group(`Cache: ${name}`);
        urls2.forEach((url) => console.log("- " + url));
        console.groupEnd();
      });
      console.groupEnd();
      return allCaches;
    }
    const cache = await caches.open(cacheName);
    const keys = await cache.keys();
    const urls = keys.map((key) => key.url);
    console.group(`Cache Contents (${cacheName}):`);
    urls.forEach((url) => console.log("- " + url));
    console.groupEnd();
    return { [cacheName]: urls };
  } catch (error) {
    console.error("Error inspecting cache:", error);
    return null;
  }
};
const clearCache = async (cacheName) => {
  try {
    if (cacheName) {
      await caches.delete(cacheName);
      console.log(`Cleared cache: ${cacheName}`);
    } else {
      const keys = await caches.keys();
      await Promise.all(keys.map((key) => caches.delete(key)));
      console.log("Cleared all caches");
    }
    return true;
  } catch (error) {
    console.error("Error clearing cache:", error);
    return false;
  }
};

export { CacheProvider, clearCache, inspectCache, useStaticCache };
//# sourceMappingURL=index.esm.js.map
